Handle "multiimgoem", "multiimgqti" partitions.

Handle "multiimgoem", "multiimgqti" partitions, similar to other
partitions in BOOT LUN.

Change-Id: I41c3458af4520ac28b7a72ae300cebd74a4db00c
CRs-Fixed:: 2897043
diff --git a/1.1/libboot_control_qti/libboot_control_qti.cpp b/1.1/libboot_control_qti/libboot_control_qti.cpp
index f476e95..1a36300 100644
--- a/1.1/libboot_control_qti/libboot_control_qti.cpp
+++ b/1.1/libboot_control_qti/libboot_control_qti.cpp
@@ -513,14 +513,12 @@
 	//actual names. To do this we append the slot suffix to every member
 	//in the list.
 	for (i = 0; i < ARRAY_SIZE(ptn_list); i++) {
-		//XBL & XBL_CFG are handled differrently for ufs devices so
-		//ignore them
-		if (is_ufs && (!strncmp(ptn_list[i],
-						PTN_XBL,
-						strlen(PTN_XBL))
-					|| !strncmp(ptn_list[i],
-						PTN_XBL_CFG,
-						strlen(PTN_XBL_CFG))))
+		//XBL, XBL_CFG, MULTIIMGOEM, MULTIIMGQTI are handled differrently
+               //for ufs devices so ignore them.
+		if (is_ufs && (!strncmp(ptn_list[i],PTN_XBL,strlen(PTN_XBL))
+		    || !strncmp(ptn_list[i],PTN_XBL_CFG,strlen(PTN_XBL_CFG))
+                    || !strncmp(ptn_list[i],PTN_MULTIIMGOEM,strlen(PTN_MULTIIMGOEM))
+                    || !strncmp(ptn_list[i],PTN_MULTIIMGQTI,strlen(PTN_MULTIIMGQTI))))
 				continue;
 		//The partition list will be the list of _a partitions
 		string cur_ptn = ptn_list[i];
diff --git a/boot_control.cpp b/boot_control.cpp
index 899b6e2..6e11d2e 100644
--- a/boot_control.cpp
+++ b/boot_control.cpp
@@ -536,14 +536,12 @@
 	//actual names. To do this we append the slot suffix to every member
 	//in the list.
 	for (i = 0; i < ARRAY_SIZE(ptn_list); i++) {
-		//XBL & XBL_CFG are handled differrently for ufs devices so
-		//ignore them
-		if (is_ufs && (!strncmp(ptn_list[i],
-						PTN_XBL,
-						strlen(PTN_XBL))
-					|| !strncmp(ptn_list[i],
-						PTN_XBL_CFG,
-						strlen(PTN_XBL_CFG))))
+		//XBL, XBL_CFG, MULTIIMGOEM, MULTIIMGQTI are handled differrently
+               //for ufs devices so ignore them.
+		if (is_ufs && (!strncmp(ptn_list[i],PTN_XBL,strlen(PTN_XBL))
+		    || !strncmp(ptn_list[i],PTN_XBL_CFG,strlen(PTN_XBL_CFG))
+                    || !strncmp(ptn_list[i],PTN_MULTIIMGOEM,strlen(PTN_MULTIIMGOEM))
+                    || !strncmp(ptn_list[i],PTN_MULTIIMGQTI,strlen(PTN_MULTIIMGQTI))))
 				continue;
 		//The partition list will be the list of _a partitions
 		string cur_ptn = ptn_list[i];